# 013

|                                                                                  | Oven type 2          |
|:---------------------------------------------------------------------------------|:---------------------|
| bindTime                                                                         | 1711555870240        |
| createTime                                                                       | 0                    |
| deviceFeatureCode                                                                | 000                  |
| deviceFeatureName                                                                | ConnectlifeOVEN      |
| deviceId                                                                         | <redacted>           |
| deviceNickName                                                                   | BIO 21               |
| deviceTypeCode                                                                   | 013                  |
| deviceTypeName                                                                   |                      |
| offlineState                                                                     | 1                    |
| puid                                                                             | <redacted>           |
| role                                                                             | 2                    |
| roomId                                                                           | 106345               |
| roomName                                                                         | default_room         |
| seq                                                                              | 0                    |
| statusList.Adaptive_sense_setting                                                | 1                    |
| statusList.Add_moist_now                                                         | 0                    |
| statusList.AlarmAlmost_finished                                                  | 0                    |
| statusList.AlarmChild_lockOff                                                    | 0                    |
| statusList.AlarmChild_lockOn                                                     | 0                    |
| statusList.AlarmCleanTank                                                        | 0                    |
| statusList.AlarmDehydrate_ended                                                  | 0                    |
| statusList.AlarmDemo_activated                                                   | 0                    |
| statusList.AlarmDescaleStep1                                                     | 0                    |
| statusList.AlarmDescaleStep2                                                     | 0                    |
| statusList.AlarmDescaleStep3                                                     | 0                    |
| statusList.AlarmDescaling_interrupted                                            | 0                    |
| statusList.AlarmEmptyTankPause                                                   | 0                    |
| statusList.AlarmFillTank                                                         | 0                    |
| statusList.AlarmIncreased_power_consumption                                      | 0                    |
| statusList.AlarmKey_lock_on                                                      | 0                    |
| statusList.AlarmMicrowave_system_finished                                        | 0                    |
| statusList.AlarmOven_system_finished                                             | 0                    |
| statusList.AlarmPopTankOpened                                                    | 0                    |
| statusList.AlarmPower_failure_running                                            | 0                    |
| statusList.AlarmProbe_lost_connection                                            | 0                    |
| statusList.AlarmRemoteStartPowerFailure                                          | 0                    |
| statusList.AlarmRemove_probe                                                     | 0                    |
| statusList.AlarmSabbathAboutToStart                                              | 0                    |
| statusList.AlarmSabbathEnded                                                     | 0                    |
| statusList.AlarmSabbathPostpone                                                  | 0                    |
| statusList.AlarmSteamClean_finished                                              | 0                    |
| statusList.AlarmSteam_interrupted                                                | 0                    |
| statusList.AlarmSteam_system_finished                                            | 0                    |
| statusList.AlarmTankLevel1                                                       | 0                    |
| statusList.Alarm_aquaClean_finished                                              | 0                    |
| statusList.Alarm_baking_finished                                                 | 1                    |
| statusList.Alarm_baking_stoped                                                   | 0                    |
| statusList.Alarm_child_lock_deactivated_on_the_oven                              | 1                    |
| statusList.Alarm_cleaning_suggestion_after_baking_finished                       | 0                    |
| statusList.Alarm_defrost_finished                                                | 0                    |
| statusList.Alarm_descaling_needed                                                | 1                    |
| statusList.Alarm_door_locked                                                     | 0                    |
| statusList.Alarm_door_opened                                                     | 1                    |
| statusList.Alarm_ean_scan_info                                                   | 0                    |
| statusList.Alarm_empty_and_clean_water_tank                                      | 0                    |
| statusList.Alarm_fast_preheat_active                                             | 0                    |
| statusList.Alarm_fast_preheating_finished                                        | 1                    |
| statusList.Alarm_keepWarm_ended                                                  | 0                    |
| statusList.Alarm_mw_active                                                       | 0                    |
| statusList.Alarm_oven_temperature_too_high                                       | 0                    |
| statusList.Alarm_oven_usage_reached_set_limit_auto_cleaning_suggested            | 0                    |
| statusList.Alarm_plateWarm_ended                                                 | 0                    |
| statusList.Alarm_probe_inserted                                                  | 1                    |
| statusList.Alarm_probe_temp_reached                                              | 0                    |
| statusList.Alarm_pyrolytic_finished                                              | 0                    |
| statusList.Alarm_running_time_over_10_or_24_hour_limit_error                     | 0                    |
| statusList.Alarm_sabbath_reminder                                                | 0                    |
| statusList.Alarm_sand_timer_1_elapsed                                            | 1                    |
| statusList.Alarm_sand_timer_2_elapsed                                            | 0                    |
| statusList.Alarm_sand_timer_3_elapsed                                            | 0                    |
| statusList.Alarm_set_temperature_reached                                         | 1                    |
| statusList.Alarm_steam_fill_alarm                                                | 0                    |
| statusList.Alarm_steam_function_active                                           | 0                    |
| statusList.Alarm_turn_food                                                       | 0                    |
| statusList.Alarm_user_interaction_on_appliance_detected                          | 1                    |
| statusList.Alarm_water_tank_is_empty                                             | 0                    |
| statusList.Alarm_water_tank_is_missing                                           | 0                    |
| statusList.Almost_finished_notification_setting                                  | 0                    |
| statusList.Almost_finished_notification_settingTimer_in_minutes                  | 0                    |
| statusList.Ambient_sound_setting                                                 | 0                    |
| statusList.Auto_fast_preheat                                                     | 1                    |
| statusList.AutomaticChild_lock_setting                                           | 0                    |
| statusList.AutomaticDoor_lock_setting                                            | 0                    |
| statusList.AutomaticDoor_lock_setting_allowed                                    | 0                    |
| statusList.Automatic_display_brightness_setting                                  | 0                    |
| statusList.Automatic_door_closing_at_program_start_setting                       | 0                    |
| statusList.Automatic_door_open_at_program_end_after_time_setting                 | 0                    |
| statusList.Automatic_door_open_at_program_end_after_time_settingTimer_in_minutes | 0                    |
| statusList.Automatic_door_open_at_program_end_setting                            | 0                    |
| statusList.Automatic_water_tank_opening_setting                                  | 0                    |
| statusList.Baking_steps_intensity_levels                                         | 0                    |
| statusList.Baking_steps_intensity_levels_type                                    | 0                    |
| statusList.Brand_splash_setting                                                  | 0                    |
| statusList.Brightness                                                            | 3                    |
| statusList.CameraLive_feed_current_phase                                         | 0                    |
| statusList.CameraLive_feed_status                                                | 0                    |
| statusList.CameraPicture_current_phase                                           | 0                    |
| statusList.CameraPicture_request                                                 | 0                    |
| statusList.CameraTime_lapse_current_phase                                        | 0                    |
| statusList.CameraTime_lapse_request                                              | 0                    |
| statusList.Camera_enable_setting                                                 | 0                    |
| statusList.Camera_status                                                         | 0                    |
| statusList.Child_lock                                                            | 1                    |
| statusList.Cooking_intensity                                                     | 0                    |
| statusList.Crisp_function_available                                              | 0                    |
| statusList.Crisp_function_status                                                 | 0                    |
| statusList.Current_baking_step                                                   | 2                    |
| statusList.Current_baking_step2                                                  | 0                    |
| statusList.Date_format_setting                                                   | 0                    |
| statusList.Demo_mode                                                             | 1                    |
| statusList.Descale_status                                                        | 0                    |
| statusList.DisplayBrightness_setting                                             | 0                    |
| statusList.DisplayContrast_setting                                               | 0                    |
| statusList.Display_standby                                                       | 0                    |
| statusList.Display_switch_to_standby_after_minutes                               | 0                    |
| statusList.Door                                                                  | 1                    |
| statusList.Door_lock                                                             | 2                    |
| statusList.Door_lock_status                                                      | 0                    |
| statusList.Door_open_notification_setting                                        | 0                    |
| statusList.Door_sensor_setting                                                   | 0                    |
| statusList.Duration_of_clock                                                     | 0                    |
| statusList.Eco_mode_setting                                                      | 0                    |
| statusList.Error_0                                                               | 1                    |
| statusList.Error_1                                                               | 1                    |
| statusList.Error_10                                                              | 0                    |
| statusList.Error_11                                                              | 0                    |
| statusList.Error_12                                                              | 1                    |
| statusList.Error_13                                                              | 1                    |
| statusList.Error_14                                                              | 0                    |
| statusList.Error_15                                                              | 0                    |
| statusList.Error_16                                                              | 1                    |
| statusList.Error_17                                                              | 1                    |
| statusList.Error_18                                                              | 0                    |
| statusList.Error_19                                                              | 0                    |
| statusList.Error_2                                                               | 0                    |
| statusList.Error_20                                                              | 1                    |
| statusList.Error_21                                                              | 1                    |
| statusList.Error_22                                                              | 0                    |
| statusList.Error_23                                                              | 0                    |
| statusList.Error_24                                                              | 1                    |
| statusList.Error_25                                                              | 1                    |
| statusList.Error_26                                                              | 0                    |
| statusList.Error_27                                                              | 0                    |
| statusList.Error_28                                                              | 1                    |
| statusList.Error_29                                                              | 0                    |
| statusList.Error_3                                                               | 0                    |
| statusList.Error_30                                                              | 0                    |
| statusList.Error_31                                                              | 1                    |
| statusList.Error_32                                                              | 1                    |
| statusList.Error_33                                                              | 0                    |
| statusList.Error_34                                                              | 0                    |
| statusList.Error_35                                                              | 0                    |
| statusList.Error_36                                                              | 0                    |
| statusList.Error_37                                                              | 0                    |
| statusList.Error_38                                                              | 0                    |
| statusList.Error_39                                                              | 0                    |
| statusList.Error_4                                                               | 1                    |
| statusList.Error_40                                                              | 0                    |
| statusList.Error_5                                                               | 1                    |
| statusList.Error_6                                                               | 0                    |
| statusList.Error_7                                                               | 0                    |
| statusList.Error_8                                                               | 1                    |
| statusList.Error_9                                                               | 1                    |
| statusList.Factory_reset                                                         | 0                    |
| statusList.Fota                                                                  | 0                    |
| statusList.Gratin_available                                                      | 0                    |
| statusList.Gratin_from_below_functionSet_time_in_seconds                         | 0                    |
| statusList.Gratin_from_below_function_allowed                                    | 0                    |
| statusList.Gratin_from_below_function_status                                     | 0                    |
| statusList.Gratin_function_Set_time_in_seconds                                   | 0                    |
| statusList.Gratin_status                                                         | 1                    |
| statusList.Gratin_total_allowed_time_in_minutes                                  | 30                   |
| statusList.Gratin_total_passed_time_in_minutes                                   | 65535                |
| statusList.Grill_plate_measured_temperature                                      | 4484                 |
| statusList.Grill_plate_status                                                    | 0                    |
| statusList.HOB_warming_zone_power_level                                          | 0                    |
| statusList.HOB_warming_zone_status                                               | 0                    |
| statusList.HardPairingStatus                                                     | 0                    |
| statusList.Hide_setting                                                          | 0                    |
| statusList.Hob_status                                                            | 0                    |
| statusList.Hob_zone_1_status                                                     | 0                    |
| statusList.Hob_zone_2_status                                                     | 0                    |
| statusList.Hob_zone_3_status                                                     | 0                    |
| statusList.Hob_zone_4_status                                                     | 0                    |
| statusList.Hob_zone_5_status                                                     | 0                    |
| statusList.Inactivity_timeout                                                    | 0                    |
| statusList.Interior_Light_Control_available                                      | 0                    |
| statusList.Interior_light                                                        | 1                    |
| statusList.Key_sound                                                             | 2                    |
| statusList.Language_status                                                       | 0                    |
| statusList.LightsBrightness_setting                                              | 0                    |
| statusList.LightsColor_temperature_setting                                       | 0                    |
| statusList.Lights_duration_setting                                               | 0                    |
| statusList.LockPIN_code                                                          | 0                    |
| statusList.Meat_probe_measured_temperature                                       | 65535                |
| statusList.Meat_probe_set_temperature                                            | 65535                |
| statusList.Meat_probe_status                                                     | 1                    |
| statusList.Navigation_sound_setting                                              | 0                    |
| statusList.Night_modeDisplay_brightness_setting                                  | 0                    |
| statusList.Night_modeLight_brightness_setting                                    | 0                    |
| statusList.Night_modeVolume_setting                                              | 0                    |
| statusList.Night_mode_off_hour                                                   | 255                  |
| statusList.Night_mode_off_minute                                                 | 255                  |
| statusList.Night_mode_on_hour                                                    | 255                  |
| statusList.Night_mode_on_minute                                                  | 255                  |
| statusList.Night_mode_status                                                     | 1                    |
| statusList.Notification_pitch_sound_setting                                      | 0                    |
| statusList.Notification_sounds_volume_setting                                    | 0                    |
| statusList.Oven_measured_temperature                                             | 0                    |
| statusList.Oven_temperature_unit                                                 | 1                    |
| statusList.Oven_temperature_unit_setting                                         | 1                    |
| statusList.Oven_usage_value_alarm_limit                                          | 0                    |
| statusList.Oven_usage_value_time_since_last_cleaning                             | 65535                |
| statusList.Permanent_remote_start                                                | 0                    |
| statusList.Program_settingsDefault                                               | 0                    |
| statusList.Program_settingsStart_key_duation_forMW                               | 0                    |
| statusList.Proximity_sensor_setting                                              | 0                    |
| statusList.Proximity_sensor_settingClose_user_detectedDisplay_change_to          | 0                    |
| statusList.Proximity_sensor_settingClose_user_detectedLight_change_to            | 0                    |
| statusList.Proximity_sensor_settingDistant_user_detectedDisplay_change_to        | 0                    |
| statusList.Proximity_sensor_settingDistant_user_detectedLight_change_to          | 0                    |
| statusList.Remote_control_monitoring                                             | 0                    |
| statusList.Remote_control_monitoring_set_commands                                | 1                    |
| statusList.Remote_control_monitoring_set_commands_actions                        | 0                    |
| statusList.Remove_moist_now                                                      | 0                    |
| statusList.Reset_to_default                                                      | 0                    |
| statusList.Sabbath_mode_setting                                                  | 0                    |
| statusList.Sabbath_mode_settingBakingEnd_atHour                                  | 0                    |
| statusList.Sabbath_mode_settingBakingEnd_atMinute                                | 0                    |
| statusList.Sabbath_mode_settingBakingStart_atHour                                | 0                    |
| statusList.Sabbath_mode_settingBakingStart_atMinute                              | 0                    |
| statusList.Sabbath_mode_settingCavity_light_during_sabbath                       | 0                    |
| statusList.Sabbath_mode_settingEnd_timeHour                                      | 0                    |
| statusList.Sabbath_mode_settingEnd_timeMinute                                    | 0                    |
| statusList.Sabbath_mode_settingSet_heater_system                                 | 0                    |
| statusList.Sabbath_mode_settingStart_timeHour                                    | 0                    |
| statusList.Sabbath_mode_settingStart_timeMinute                                  | 0                    |
| statusList.Sabbath_mode_setting_activate_weekly                                  | 0                    |
| statusList.Sabbath_mode_status                                                   | 1                    |
| statusList.Sand_timer_1_duration_hours                                           | 255                  |
| statusList.Sand_timer_1_duration_minutes                                         | 255                  |
| statusList.Sand_timer_1_duration_seconds                                         | 255                  |
| statusList.Sand_timer_1_end_utc_datetime_bdc_timestamp                           | 16679/02/18T23:47:45 |
| statusList.Sand_timer_1_paused_total_seconds                                     | 65535                |
| statusList.Sand_timer_1_start_utc_datetime_bdc_timestamp                         | 16679/02/18T23:47:45 |
| statusList.Sand_timer_1_status                                                   | 5                    |
| statusList.Sand_timer_2_duration_hours                                           | 255                  |
| statusList.Sand_timer_2_duration_minutes                                         | 255                  |
| statusList.Sand_timer_2_duration_seconds                                         | 255                  |
| statusList.Sand_timer_2_end_utc_datetime_bdc_timestamp                           | 16679/02/18T23:47:45 |
| statusList.Sand_timer_2_paused_total_seconds                                     | 65535                |
| statusList.Sand_timer_2_start_utc_datetime_bdc_timestamp                         | 16679/02/18T23:47:45 |
| statusList.Sand_timer_2_status                                                   | 0                    |
| statusList.Sand_timer_3_duration_hours                                           | 255                  |
| statusList.Sand_timer_3_duration_minutes                                         | 255                  |
| statusList.Sand_timer_3_duration_seconds                                         | 255                  |
| statusList.Sand_timer_3_end_utc_datetime_bdc_timestamp                           | 16679/02/18T23:47:45 |
| statusList.Sand_timer_3_paused_total_seconds                                     | 65535                |
| statusList.Sand_timer_3_start_utc_datetime_bdc_timestamp                         | 16679/02/18T23:47:45 |
| statusList.Sand_timer_3_status                                                   | 7                    |
| statusList.Scanned_EAN_code                                                      | -12-500000000000     |
| statusList.Session_pairing_active                                                | 0                    |
| statusList.Session_pairing_setting                                               | 0                    |
| statusList.Set_time_Hour                                                         | 0                    |
| statusList.Set_time_Minutes                                                      | 0                    |
| statusList.Settings_day                                                          | 255                  |
| statusList.Settings_hour                                                         | 16                   |
| statusList.Settings_minute                                                       | 31                   |
| statusList.Settings_month                                                        | 255                  |
| statusList.Settings_year                                                         | 65535                |
| statusList.Shop_mode_setting                                                     | 0                    |
| statusList.Show_date_setting                                                     | 0                    |
| statusList.Soft_pairing_setting                                                  | 0                    |
| statusList.Stage_lights_setting                                                  | 0                    |
| statusList.Status                                                                | 1                    |
| statusList.Steam123_0_available                                                  | 0                    |
| statusList.Steam123_1_available                                                  | 0                    |
| statusList.Steam123_2_available                                                  | 0                    |
| statusList.Steam123_3_available                                                  | 0                    |
| statusList.Steam_123                                                             | 0                    |
| statusList.Steam_assist_Time_used                                                | 0                    |
| statusList.Steam_reduction_at_door_opening_setting                               | 0                    |
| statusList.Steam_reduction_at_program_end_setting                                | 0                    |
| statusList.Steam_shot                                                            | 0                    |
| statusList.Step1Add_moistStart_at_minute                                         | 0                    |
| statusList.Step1Add_moistValve_open_percentage                                   | 0                    |
| statusList.Step1Add_moist_status                                                 | 0                    |
| statusList.Step1Alarm_after_step                                                 | 0                    |
| statusList.Step1Grill_intensity                                                  | 0                    |
| statusList.Step1Pause_after_step                                                 | 0                    |
| statusList.Step1Remove_moistStart_at_minute                                      | 0                    |
| statusList.Step1_Steam_assist                                                    | 0                    |
| statusList.Step1_Steam_assistSet_time_in_minutes                                 | 0                    |
| statusList.Step1_Steam_assist_intensity                                          | 0                    |
| statusList.Step1_setMulti_level_baking                                           | 0                    |
| statusList.Step2Add_moistStart_at_minute                                         | 0                    |
| statusList.Step2Add_moistValve_open_percentage                                   | 0                    |
| statusList.Step2Add_moist_status                                                 | 0                    |
| statusList.Step2Alarm_after_step                                                 | 0                    |
| statusList.Step2Grill_intensity                                                  | 0                    |
| statusList.Step2Pause_after_step                                                 | 0                    |
| statusList.Step2Remove_moistStart_at_minute                                      | 0                    |
| statusList.Step2_Steam_assist                                                    | 0                    |
| statusList.Step2_Steam_assistSet_time_in_minutes                                 | 0                    |
| statusList.Step2_Steam_assist_intensity                                          | 0                    |
| statusList.Step2_setMulti_level_baking                                           | 0                    |
| statusList.Step3Add_moistStart_at_minute                                         | 0                    |
| statusList.Step3Add_moistValve_open_percentage                                   | 0                    |
| statusList.Step3Add_moist_status                                                 | 0                    |
| statusList.Step3Alarm_after_step                                                 | 0                    |
| statusList.Step3Grill_intensity                                                  | 0                    |
| statusList.Step3Pause_after_step                                                 | 0                    |
| statusList.Step3Remove_moistStart_at_minute                                      | 0                    |
| statusList.Step3_Steam_assist                                                    | 0                    |
| statusList.Step3_Steam_assistSet_time_in_minutes                                 | 0                    |
| statusList.Step3_Steam_assist_intensity                                          | 0                    |
| statusList.Step3_setMulti_level_baking                                           | 0                    |
| statusList.Step4Add_moistStart_at_minute                                         | 0                    |
| statusList.Step4Add_moistValve_open_percentage                                   | 0                    |
| statusList.Step4Add_moist_status                                                 | 0                    |
| statusList.Step4Alarm_after_step                                                 | 0                    |
| statusList.Step4Grill_intensity                                                  | 0                    |
| statusList.Step4Pause_after_step                                                 | 0                    |
| statusList.Step4Remove_moistStart_at_minute                                      | 0                    |
| statusList.Step4Steam_assist                                                     | 0                    |
| statusList.Step4Steam_assistSet_time_in_minutes                                  | 0                    |
| statusList.Step4Steam_assist_intensity                                           | 0                    |
| statusList.Step4_bake_mode                                                       | 0                    |
| statusList.Step4_duration                                                        | 0                    |
| statusList.Step4_passed_time                                                     | 0                    |
| statusList.Step4_remaining_time                                                  | 0                    |
| statusList.Step4_setMulti_level_baking                                           | 0                    |
| statusList.Step4_set_heater_system                                               | 0                    |
| statusList.Step4_set_microwave_wattage                                           | 0                    |
| statusList.Step4_set_temperature                                                 | 0                    |
| statusList.Step4_status                                                          | 0                    |
| statusList.Step4_steam_available                                                 | 0                    |
| statusList.Step4_time_unit                                                       | 0                    |
| statusList.Step5Add_moistStart_at_minute                                         | 0                    |
| statusList.Step5Add_moistValve_open_percentage                                   | 0                    |
| statusList.Step5Add_moist_status                                                 | 0                    |
| statusList.Step5Alarm_after_step                                                 | 0                    |
| statusList.Step5Grill_intensity                                                  | 0                    |
| statusList.Step5Pause_after_step                                                 | 0                    |
| statusList.Step5Remove_moistStart_at_minute                                      | 0                    |
| statusList.Step5Steam_assist                                                     | 0                    |
| statusList.Step5Steam_assistSet_time_in_minutes                                  | 0                    |
| statusList.Step5Steam_assist_intensity                                           | 0                    |
| statusList.Step5_bake_mode                                                       | 0                    |
| statusList.Step5_duration                                                        | 0                    |
| statusList.Step5_passed_time                                                     | 0                    |
| statusList.Step5_remaining_time                                                  | 0                    |
| statusList.Step5_setMulti_level_baking                                           | 0                    |
| statusList.Step5_set_heater_system                                               | 0                    |
| statusList.Step5_set_microwave_wattage                                           | 0                    |
| statusList.Step5_set_temperature                                                 | 0                    |
| statusList.Step5_status                                                          | 0                    |
| statusList.Step5_steam_available                                                 | 0                    |
| statusList.Step5_time_unit                                                       | 0                    |
| statusList.Step_1_bake_mode                                                      | 3                    |
| statusList.Step_1_duration                                                       | 0                    |
| statusList.Step_1_fastpreheat_function                                           | 0                    |
| statusList.Step_1_passed_time                                                    | 16777215             |
| statusList.Step_1_remaining_time                                                 | 16777215             |
| statusList.Step_1_set_heater_system                                              | 0                    |
| statusList.Step_1_set_microwave_wattage                                          | 0                    |
| statusList.Step_1_set_temperature                                                | 0                    |
| statusList.Step_1_status                                                         | 1                    |
| statusList.Step_1_steam_available                                                | 0                    |
| statusList.Step_1_time_unit                                                      | 2                    |
| statusList.Step_2_bake_mode                                                      | 0                    |
| statusList.Step_2_duration                                                       | 0                    |
| statusList.Step_2_passed_time                                                    | 16777215             |
| statusList.Step_2_remaining_time                                                 | 0                    |
| statusList.Step_2_set_heater_system                                              | 66                   |
| statusList.Step_2_set_microwave_wattage                                          | 0                    |
| statusList.Step_2_set_temperature                                                | 0                    |
| statusList.Step_2_status                                                         | 2                    |
| statusList.Step_2_steam_available                                                | 0                    |
| statusList.Step_2_time_unit                                                      | 2                    |
| statusList.Step_3_bake_mode                                                      | 0                    |
| statusList.Step_3_duration                                                       | 16777215             |
| statusList.Step_3_passed_time                                                    | 16777215             |
| statusList.Step_3_remaining_time                                                 | 16777215             |
| statusList.Step_3_set_heater_system                                              | 0                    |
| statusList.Step_3_set_microwave_wattage                                          | 0                    |
| statusList.Step_3_set_temperature                                                | 65535                |
| statusList.Step_3_status                                                         | 0                    |
| statusList.Step_3_steam_available                                                | 0                    |
| statusList.Step_3_time_unit                                                      | 0                    |
| statusList.Step_after_bakeAdd_moistStart_at_minute                               | 0                    |
| statusList.Step_after_bakeAdd_moistValve_open_percentage                         | 0                    |
| statusList.Step_after_bakeAdd_moist_status                                       | 0                    |
| statusList.Step_after_bakeRemove_moistStart_at_minute                            | 0                    |
| statusList.Step_after_bake_duration                                              | 16777215             |
| statusList.Step_after_bake_mode                                                  | 0                    |
| statusList.Step_after_bake_passed_time                                           | 16777215             |
| statusList.Step_after_bake_remaining_Time                                        | 16777215             |
| statusList.Step_after_bake_setMulti_level_baking                                 | 0                    |
| statusList.Step_after_bake_set_heater_system                                     | 0                    |
| statusList.Step_after_bake_set_temperature                                       | 65535                |
| statusList.Step_after_bake_status                                                | 0                    |
| statusList.Step_after_bake_time_unit                                             | 0                    |
| statusList.Step_pre_bakeAdd_moistStart_at_minute                                 | 0                    |
| statusList.Step_pre_bakeAdd_moistValve_open_percentage                           | 0                    |
| statusList.Step_pre_bakeAdd_moist_status                                         | 0                    |
| statusList.Step_pre_bakeRemove_moistStart_at_minute                              | 0                    |
| statusList.Step_pre_bake_duration                                                | 16777215             |
| statusList.Step_pre_bake_mode                                                    | 0                    |
| statusList.Step_pre_bake_passed_time                                             | 16777215             |
| statusList.Step_pre_bake_remaining_time                                          | 16777215             |
| statusList.Step_pre_bake_setMulti_level_baking                                   | 0                    |
| statusList.Step_pre_bake_set_heater_system                                       | 0                    |
| statusList.Step_pre_bake_set_temperature                                         | 0                    |
| statusList.Step_pre_bake_status                                                  | 1                    |
| statusList.Step_pre_bake_time_unit                                               | 2                    |
| statusList.SummerWinter_timeAutomatic_setting                                    | 0                    |
| statusList.Temperature_reached_notification_setting                              | 0                    |
| statusList.Text_size_setting                                                     | 0                    |
| statusList.TimeDateAutomatic_setting                                             | 0                    |
| statusList.Time_format                                                           | 2                    |
| statusList.Time_zone_setting                                                     | 0                    |
| statusList.Total_duration_in_seconds                                             | 16777215             |
| statusList.Total_oven_usage_value                                                | 65535                |
| statusList.Total_passed_time_seconds                                             | 16777215             |
| statusList.Total_remaining_time_seconds                                          | 16777215             |
| statusList.Volume                                                                | 4                    |
| statusList.Volume_setting                                                        | 0                    |
| statusList.Warming_drawer_power_level                                            | 0                    |
| statusList.Warming_drawer_status                                                 | 0                    |
| statusList.Water_hardness                                                        | 3                    |
| statusList.Water_tank                                                            | 0                    |
| statusList.Water_tank_level                                                      | 0                    |
| statusList.Weight_unit_setting                                                   | 0                    |
| statusList.Welcome                                                               | 0                    |
| statusList.daily_energy_kwh                                                      | 0                    |
| useTime                                                                          | 0                    |
| wifiId                                                                           | <redacted>           |

## Generated from

- [`Oven_type_2.json`](Oven_type_2.json)
